@@ -1,6 +1,6 @@
 ;;; abbrev.scm  --  Determining abbreviations.
 ;;;
-;;; Copyright 2006  Ludovic Courts <ludovic.courtes@laas.fr>
+;;; Copyright 2006, 2020 Ludovic Courts <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -19,11 +19,11 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo biblio abbrev)
-  :use-module (srfi srfi-13)
-  :autoload   (skribilo ast)           (markup? markup-body-set!)
-  :autoload   (skribilo utils strings) (make-string-replace)
-  :autoload   (ice-9 regex)      (regexp-substitute/global)
-  :export (is-abbreviation? is-acronym? abbreviate-word
+  #:use-module (srfi srfi-13)
+  #:use-module (skribilo ast)
+  #:autoload   (skribilo utils strings) (make-string-replace)
+  #:autoload   (ice-9 regex)      (regexp-substitute/global)
+  #:export (is-abbreviation? is-acronym? abbreviate-word
            abbreviate-string abbreviate-markup
 
            %cs-conference-abbreviations
