@@ -2,7 +2,7 @@
 ;;;
 ;;; Copyright 2005, 2006, 2007, 2008, 2009, 2011, 2012, 2018, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
-;;; Copyright 2022, 2023 Arun Isaac <arunisaac@systemreboot.net>
+;;; Copyright 2022, 2023, 2026 Arun Isaac <arunisaac@systemreboot.net>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -52,7 +52,8 @@
 
   #:export (html-engine html-title-engine html-file
            html-width html-class html-markup-class
-           html-title-authors))
+           html-title-authors html-open html-close
+           style-declaration html-color-spec?))
 
 (skribilo-module-syntax)
 
@@ -582,11 +583,12 @@
 ;*---------------------------------------------------------------------*/
 ;*    html-open ...                                                    */
 ;*---------------------------------------------------------------------*/
-(define* (html-open tag #:optional (attributes '()))
+(define* (html-open tag #:optional (attributes '()) (newline? #t))
   "Output opening TAG with ATTRIBUTES, an association list mapping
 attribute names to their values. Attribute names may be symbols or
 strings. Values may be symbols, strings or numbers. Attributes with
-unspecified or #f values are ignored."
+unspecified or #f values are ignored. If NEWLINE? is #t, add a newline
+at the end."
   (display "<")
   (display tag)
   (for-each (match-lambda
@@ -596,7 +598,8 @@ unspecified or #f values are ignored."
                  (format #t " ~a=\"~a\"" name value))))
             attributes)
   (display ">")
-  (newline))
+  (when newline?
+    (newline)))
 
 ;*---------------------------------------------------------------------*/
 ;*    html-close ...                                                   */
@@ -629,10 +632,11 @@ ignored, return #f."
 ;*---------------------------------------------------------------------*/
 ;*    html-markup-class ...                                            */
 ;*---------------------------------------------------------------------*/
-(define (html-markup-class m)
+(define* (html-markup-class m #:optional (newline? #t))
   (lambda (node engine)
     (html-open m
-               `((class . ,(markup-class node))))))
+               `((class . ,(markup-class node)))
+               newline?)))
 
 ;*---------------------------------------------------------------------*/
 ;*    html-color-spec? ...                                             */
@@ -670,8 +674,7 @@ ignored, return #f."
 ;*    &html-html ...                                                   */
 ;*---------------------------------------------------------------------*/
 (markup-writer '&html-html
-   :before "<!-- 95% W3C COMPLIANT, 95% CSS FREE, RAW HTML -->
-<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">
+   :before "<!DOCTYPE html>
 <html>\n"
    :after "</html>")
 
@@ -973,17 +976,16 @@ ignored, return #f."
 	  (title-foreground (engine-custom engine 'title-foreground))
 	  (title-font (engine-custom engine 'title-font)))
       (when title
-        (html-open 'div
+        (html-open 'h1
                    `((class . "skribilo-title")
                      (style . ,(style-declaration
                                 `((color . ,(and (html-color-spec? title-foreground)
                                                  title-foreground))
                                   (background-color . ,(and (html-color-spec? title-background)
                                                             title-background))
-                                  (font-family . ,title-font)
-                                  (text-align . "center"))))))
+                                  (font-family . ,title-font))))))
         (output title engine)
-        (html-close 'div)
+        (html-close 'h1)
         (when authors
           (html-title-authors authors engine)))))
 
@@ -1048,11 +1050,8 @@ ignored, return #f."
      (html-open 'div
                 `((style . ,(style-declaration
                              '((text-align . "center"))))))
-     (display (string-join (map (lambda (author)
-                                  (with-output-to-string
-                                    (cut output author engine)))
-                                authors)
-                           ", "))
+     (for-each (cut output <> engine)
+               authors)
      (html-close 'div))))
 
 ;*---------------------------------------------------------------------*/
@@ -1143,6 +1142,7 @@ ignored, return #f."
 				                                (string=? file (*destination-file*)))
 			                                   ""
 			                                   (strip-ref-base (or file (*destination-file*) "")))
+                                                       "#"
                                                        (string-canonicalize id)))))
 		                (output (markup-option parent :title)
                                         engine)
@@ -1402,7 +1402,8 @@ ignored, return #f."
       (output title engine)
       ;; title stop string
       (display title-stop)
-      (html-close 'div)))
+      (html-close 'div)
+      ((html-markup-class "div") node engine)))
 
 ;*---------------------------------------------------------------------*/
 ;*    section ...  @label section@                                     */
@@ -1541,8 +1542,9 @@ ignored, return #f."
                                                                           "px")))
                                           (width . ,(and width
                                                          (string-append (html-width width)
-                                                                        "px"))))))))))
-    :after "</span>\n")
+                                                                        "px")))))))
+                           #f)))
+    :after "</span>")
 
 ;*---------------------------------------------------------------------*/
 ;*    frame ...                                                        */
@@ -1665,10 +1667,10 @@ ignored, return #f."
 					    (markup-ident item))))
                             (html-open 'li
                                        `((class . ,(markup-class item))))
-			    (if ident  ;; produce an anchor
-                                (html-open 'a
-                                           `((name . ,(string-canonicalize ident))))
-                                (html-close 'a))
+			    (when ident  ;; produce an anchor
+                              (html-open 'a
+                                         `((name . ,(string-canonicalize ident))))
+                              (html-close 'a))
 			   (output item engine)
                            (html-close 'li)))
 			(markup-body node)))
@@ -1918,20 +1920,22 @@ ignored, return #f."
 ;*    Ornaments ...                                                    */
 ;*---------------------------------------------------------------------*/
 (markup-writer 'roman :before "")
-(markup-writer 'bold :before (html-markup-class "strong") :after "</strong>")
-(markup-writer 'underline :before (html-markup-class "u") :after "</u>")
-(markup-writer 'strike :before (html-markup-class "strike") :after "</strike>")
-(markup-writer 'emph :before (html-markup-class "em") :after "</em>")
-(markup-writer 'kbd :before (html-markup-class "kbd") :after "</kbd>")
-(markup-writer 'it :before (html-markup-class "em") :after "</em>")
-(markup-writer 'tt :before (html-markup-class "tt") :after "</tt>")
-(markup-writer 'code :before (html-markup-class "code") :after "</code>")
-(markup-writer 'var :before (html-markup-class "var") :after "</var>")
-(markup-writer 'samp :before (html-markup-class "samp") :after "</samp>")
+(markup-writer 'bold
+  :before (html-markup-class "strong" #f)
+  :after "</strong>")
+(markup-writer 'underline :before (html-markup-class "u" #f) :after "</u>")
+(markup-writer 'strike :before (html-markup-class "strike" #f) :after "</strike>")
+(markup-writer 'emph :before (html-markup-class "em" #f) :after "</em>")
+(markup-writer 'kbd :before (html-markup-class "kbd" #f) :after "</kbd>")
+(markup-writer 'it :before (html-markup-class "em" #f) :after "</em>")
+(markup-writer 'tt :before (html-markup-class "tt" #f) :after "</tt>")
+(markup-writer 'code :before (html-markup-class "code" #f) :after "</code>")
+(markup-writer 'var :before (html-markup-class "var" #f) :after "</var>")
+(markup-writer 'samp :before (html-markup-class "samp" #f) :after "</samp>")
 (markup-writer 'sc :before "<span class=\"sc\">" :after "</span>")
 (markup-writer 'sf :before "<span class=\"sf\">" :after "</span>")
-(markup-writer 'sub :before (html-markup-class "sub") :after "</sub>")
-(markup-writer 'sup :before (html-markup-class "sup") :after "</sup>")
+(markup-writer 'sub :before (html-markup-class "sub" #f) :after "</sub>")
+(markup-writer 'sup :before (html-markup-class "sup" #f) :after "</sup>")
 
 ;*---------------------------------------------------------------------*/
 ;*    q ... @label q@                                                  */
@@ -2156,7 +2160,8 @@ ignored, return #f."
                             (markup-writer-get '&prog-line base-engine))))
                (html-open 'a
                           `((class . ,(markup-class node))
-                            (name . ,(string-canonicalize (markup-ident node)))))
+                            (name . ,(string-canonicalize (markup-ident node))))
+                          #f)
                (before node engine)))
    :after "</a>\n")
 
