@@ -1,6 +1,6 @@
 ;;; lib.scm -- Utilities.                 -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2007, 2009, 2012, 2013, 2016  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2007, 2009, 2012, 2013, 2016, 2020  Ludovic Courts <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Erick Gallesio - I3S-CNRS/ESSI <eg@unice.fr>
 ;;;
 ;;;
@@ -20,8 +20,8 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo lib)
-  :use-module (skribilo utils syntax)
-  :export (skribe-ast-error skribe-error
+  #:use-module (skribilo utils syntax)
+  #:export (skribe-ast-error skribe-error
            skribe-type-error
            warning/loc
            skribe-warning
@@ -36,18 +36,18 @@
            &invocation-location)
 
   ;; Re-exported because used in `define-markup'.
-  :re-export  (invocation-location)
+  #:re-export  (invocation-location)
 
-  :use-module (skribilo ast)
+  #:use-module (skribilo ast)
 
   ;; useful for `new' to work well with <language>
-  :autoload   (skribilo source)   (<language>)
+  #:autoload   (skribilo source)   (<language>)
 
-  :use-module (skribilo parameters)
-  :use-module (skribilo location)
+  #:use-module (skribilo parameters)
+  #:use-module (skribilo location)
 
-  :use-module (srfi srfi-1)
-  :use-module (oop goops))
+  #:use-module (srfi srfi-1)
+  #:use-module (oop goops))
 
 
 (skribilo-module-syntax)
@@ -109,60 +109,44 @@
 ;; keyword style, and a couple other differences handled by
 ;; `dsssl->guile-formals'.
 
-(cond-expand
- (guile-2
-  ;; On Guile 2.0, `define-markup' generates a macro for the markup, such
-  ;; that the macro captures its invocation source location using
-  ;; `current-source-location'.
+;; On Guile 2.0, `define-markup' generates a macro for the markup, such
+;; that the macro captures its invocation source location using
+;; `current-source-location'.
 
-  (define-syntax-parameter &invocation-location
-    (identifier-syntax #f))
+(define-syntax-parameter &invocation-location
+  (identifier-syntax #f))
 
-  (define-syntax define-markup
-    (lambda (s)
-      (syntax-case s ()
-        ;; Note: Use a dotted pair for formals, to allow for dotted forms
-        ;; like: `(define-markup (foo x . rest) ...)'.
-        ((_ (name . formals) body ...)
-         (let ((formals  (map (lambda (s)
-                                (datum->syntax #'formals s))
-                              (dsssl->guile-formals (syntax->datum #'formals))))
-               (internal (symbol-append '% (syntax->datum #'name)
-                                        '-internal)))
-           (with-syntax ((internal/loc (datum->syntax #'name internal)))
-             #`(begin
-                 (define* (internal/loc loc #,@formals)
-                   (syntax-parameterize ((&invocation-location
-                                          (identifier-syntax loc)))
-                     body ...))
-                 (define-syntax name
-                   (lambda (s)
-                     (syntax-case s ()
-                       ((_ . args)
-                        #'(let ((loc (source-properties->location
+(define-syntax define-markup
+  (lambda (s)
+    (syntax-case s ()
+      ;; Note: Use a dotted pair for formals, to allow for dotted forms
+      ;; like: `(define-markup (foo x . rest) ...)'.
+      ((_ (name . formals) body ...)
+       (let ((formals  (map (lambda (s)
+                              (datum->syntax #'formals s))
+                            (dsssl->guile-formals (syntax->datum #'formals))))
+             (internal (symbol-append '% (syntax->datum #'name)
+                                      '-internal)))
+         (with-syntax ((internal/loc (datum->syntax #'name internal)))
+           #`(begin
+               (define* (internal/loc loc #,@formals)
+                 (syntax-parameterize ((&invocation-location
+                                        (identifier-syntax loc)))
+                   body ...))
+               (define-syntax name
+                 (lambda (s)
+                   (syntax-case s ()
+                     ((_ . args)
+                      #'(let ((loc (source-properties->location
+                                    (current-source-location))))
+                          (internal/loc loc . args)))
+                     (_
+                      #'(lambda args
+                          (let ((loc (source-properties->location
                                       (current-source-location))))
-                            (internal/loc loc . args)))
-                       (_
-                        #'(lambda args
-                            (let ((loc (source-properties->location
-                                        (current-source-location))))
-                              (apply internal/loc loc args)))))))
-                 internal/loc                     ; mark it as used
-                 (export name)))))))))
-
- (else                                            ; Guile 1.8
-  ;; On Guile 1.8, a markup is a procedure.  Its invocation source location
-  ;; is captured by walking the stack, which is fragile.
-
-  (define-macro (define-markup bindings . body)
-    (let ((name (car bindings))
-          (opts (cdr bindings)))
-      `(define*-public ,(cons name (dsssl->guile-formals opts))
-         ;; Memorize the invocation location.  Note: the invocation depth
-         ;; passed to `invocation-location' was determined experimentally and
-         ;; may change as Guile changes (XXX).
-         (let ((&invocation-location (invocation-location 3)))
-           ,@body))))))
+                            (apply internal/loc loc args)))))))
+               internal/loc                     ; mark it as used
+               (export name))))))))
 
 
 ;;;
