@@ -1,7 +1,6 @@
 ;;; base.scm -- The base markup package of Skribe/Skribilo.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008, 2009, 2013, 2015, 2016, 2018 Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2013, 2015, 2016, 2018, 2020 Ludovic Courtès <ludo@gnu.org>
 ;;; Copyright 2003, 2004  Manuel Serrano
 ;;;
 ;;;
@@ -21,29 +20,34 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo package base)
-  :use-module (skribilo lib)
-  :use-module (skribilo utils syntax)
-  :use-module (ice-9 optargs)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo utils syntax)
+  #:use-module (ice-9 optargs)
 
-  :use-module (skribilo ast)
-  :use-module (skribilo resolve)
-  :use-module (skribilo location)
-  :use-module (skribilo condition)
-  :use-module (skribilo utils keywords)
-  :autoload   (srfi srfi-1)        (every any filter)
-  :autoload   (skribilo evaluator) (include-document)
-  :autoload   (skribilo engine)    (engine?)
-  :autoload   (skribilo parameters)(*document-path* *sui-path*)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo resolve)
+  #:use-module (skribilo location)
+  #:use-module (skribilo condition)
+  #:use-module (skribilo utils keywords)
+  #:autoload   (srfi srfi-1)        (every any filter)
+  #:autoload   (skribilo evaluator) (include-document)
+  #:use-module (skribilo engine)
+  #:autoload   (skribilo parameters)(*document-path* *sui-path*)
 
   ;; optional ``sub-packages''
-  :autoload   (skribilo biblio)    (*bib-table* resolve-bib
-                                    bib-load! bib-add! bib-sort-refs/number)
-  :autoload   (skribilo source)    (language? source-read-lines source-fontify)
-  :autoload   (skribilo prog)      (make-prog-body resolve-line)
-  :autoload   (skribilo index)     (make-index-table default-index)
-  :autoload   (skribilo sui)       (load-sui sui-ref->url)
+  #:autoload   (skribilo biblio)    (*bib-table* resolve-bib
+                                     bib-load! bib-add! bib-sort-refs/number
+                                     bib-sort/authors assign-entries-numbers!
+                                     assign-entries-name+years!
+                                     resolve-the-bib)
+  #:autoload   (skribilo source)    (language? source-read-lines
+                                     source-fontify source-read-definition)
+  #:autoload   (skribilo prog)      (make-prog-body resolve-line)
+  #:autoload   (skribilo index)     (make-index-table default-index
+                                     index? resolve-the-index)
+  #:autoload   (skribilo sui)       (load-sui sui-ref->url)
 
-  :replace (symbol))
+  #:replace (symbol include))
 
 (skribilo-module-syntax)
 
@@ -68,12 +72,6 @@
     (invalid-argument-error 'include file 'file))
   (include-document file))
 
-(cond-expand
-  (guile-2
-   ;; On Guile 2.x, replace the 'include' core binding.
-   (module-replace! (current-module) '(include)))
-  (else #t))
-
 ;*---------------------------------------------------------------------*/
 ;*    document ...                                                     */
 ;*---------------------------------------------------------------------*/
@@ -82,7 +80,9 @@
 			 :key
 			 (ident #f) (class "document")
 			 (title #f) (html-title #f) (author #f)
-			 (ending #f) (keywords '()) (env '()))
+			 (ending #f) (keywords '()) (env '())
+                         (info-dir-category #f)
+                         (info-dir-entry ""))
    (new document
       (markup 'document)
       (ident (or ident
