@@ -1,7 +1,6 @@
 ;;; eq.scm  --  An equation formatting package.
-;;; -*- coding: iso-8859-1 -*-
 ;;;
-;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012  Ludovic Courts <ludo@gnu.org>
+;;; Copyright 2005, 2006, 2007, 2008, 2009, 2012, 2020  Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -20,25 +19,25 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo package eq)
-  :autoload   (skribilo ast)    (markup? find1-up)
-  :autoload   (skribilo output) (output)
-  :use-module (skribilo writer)
-  :use-module (skribilo engine)
-  :use-module (skribilo lib)
-  :use-module (skribilo condition)
-  :use-module (skribilo utils syntax)
-  :use-module (skribilo utils keywords) ;; `the-options', etc.
-  :use-module (skribilo package base)
-  :autoload   (skribilo engine lout)  (lout-illustration)
-  :autoload   (skribilo resolve)      (resolve-counter)
+  #:use-module (skribilo ast)
+  #:use-module (skribilo output)
+  #:use-module (skribilo writer)
+  #:use-module (skribilo engine)
+  #:use-module (skribilo lib)
+  #:use-module (skribilo condition)
+  #:use-module (skribilo utils syntax)
+  #:use-module (skribilo utils keywords) ;; `the-options', etc.
+  #:use-module (skribilo package base)
+  #:autoload   (skribilo engine lout)  (lout-illustration)
+  #:autoload   (skribilo resolve)      (resolve-counter)
 
-  :use-module (srfi srfi-1)
-  :autoload   (srfi srfi-34)          (raise)
-  :use-module (srfi srfi-35)
-  :use-module (srfi srfi-39)
-  :use-module (ice-9 optargs))
+  #:use-module (srfi srfi-1)
+  #:autoload   (srfi srfi-34)          (raise)
+  #:use-module (srfi srfi-35)
+  #:use-module (srfi srfi-39)
+  #:use-module (ice-9 optargs))
 
-;;; Author: Ludovic Courts
+;;; Author: Ludovic Courtès
 ;;;
 ;;; Commentary:
 ;;;
