@@ -1,7 +1,7 @@
 ;;; syntax.scm  --  Syntactic candy for Skribilo modules. -*- coding: utf-8 -*-
 ;;;
 ;;; Copyright 2005, 2006, 2007, 2008, 2009, 2010, 2011,
-;;;   2012, 2016, 2018 Ludovic Courtès <ludo@gnu.org>
+;;;   2012, 2016, 2018, 2020 Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;;
 ;;; This file is part of Skribilo.
@@ -20,10 +20,10 @@
 ;;; along with Skribilo.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (skribilo utils syntax)
-  :use-module (system reader library)
-  :use-module (system reader compat) ;; make sure `current-reader' exists
-  :use-module (system reader confinement)
-  :export (%skribilo-module-reader
+  #:use-module (system reader library)
+  #:use-module (system reader compat) ;; make sure `current-reader' exists
+  #:use-module (system reader confinement)
+  #:export (%skribilo-module-reader
            skribilo-module-syntax
            set-correct-file-encoding!
            default-to-utf-8
@@ -56,15 +56,7 @@
 			 "")
 		     (G_ "unexpected character in Skribilo module"))
 		    chr)))
-
-         (cond-expand
-          (guile-2 '(reader/record-positions))
-          (else
-           ;; On Guile 1.8, don't record positions by default: this yields a
-           ;; nice read performance improvement.
-           (if (memq 'positions (debug-options))
-               (list 'reader/record-positions)
-               '())))))
+         '(reader/record-positions)))
 
 (define-macro (skribilo-module-syntax)
   "Install the syntax reader for Skribilo modules."
@@ -79,49 +71,21 @@
      (lambda () ,expr1)
      (lambda () ,expr2)))
 
-(cond-expand
- ((not guile-2)
-  ;; In Guile 2.x these macros are defined in the core.
-  (begin
-    (define-macro (unless condition . exprs)
-      `(if (not ,condition)
-           ,(if (null? (cdr exprs))
-                (car exprs)
-                `(begin ,@exprs))))
+(define-syntax set-correct-file-encoding!
+  (syntax-rules ()
+    ((_)
+     (set-correct-file-encoding! (current-input-port)))
+    ((_ port)
+     ;; Use the encoding specified by the `coding:' comment.
+     (let ((e (false-if-exception (file-encoding port))))
+       (and (string? e)
+            (set-port-encoding! port e))))))
 
-    (define-macro (when condition . exprs)
-      `(if ,condition
-           ,(if (null? (cdr exprs))
-                (car exprs)
-                `(begin ,@exprs))))
-
-    (export when unless)))
- (else (begin)))
-
-(cond-expand
- (guile-2
-  (define-syntax set-correct-file-encoding!
-    (syntax-rules ()
-      ((_)
-       (set-correct-file-encoding! (current-input-port)))
-      ((_ port)
-       ;; Use the encoding specified by the `coding:' comment.
-       (let ((e (false-if-exception (file-encoding port))))
-         (and (string? e)
-              (set-port-encoding! port e))))))
-
-  (define-syntax default-to-utf-8
-    (syntax-rules ()
-      ((_ body ...)
-       (with-fluids ((%default-port-encoding "UTF-8"))
-         body ...)))))
-
- (else
-  (define-macro (set-correct-file-encoding! . p)
-    #f)
-
-  (define-macro (default-to-utf-8 . body)
-    `(begin ,@body))))
+(define-syntax default-to-utf-8
+  (syntax-rules ()
+    ((_ body ...)
+     (with-fluids ((%default-port-encoding "UTF-8"))
+       body ...))))
 
 
 ;;;
